


#ifndef GDATA_FREEBASE_ENUMS_H
#define GDATA_FREEBASE_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/usr/src/ports/mingw64-x86_64-libgdata/mingw64-x86_64-libgdata-0.17.7-1.noarch/src/libgdata-0.17.7/gdata/services/freebase/gdata-freebase-search-query.h" */
GType gdata_freebase_search_filter_type_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_FREEBASE_SEARCH_FILTER_TYPE (gdata_freebase_search_filter_type_get_type())
G_END_DECLS

#endif /* !GDATA_FREEBASE_ENUMS_H */



